@@ -71,6 +71,8 @@ from .protocol import (
     PROTOCOL_LEDENET_ADDRESSABLE_CHRISTMAS,
     PROTOCOL_LEDENET_CCT,
     PROTOCOL_LEDENET_ORIGINAL,
+    PROTOCOL_LEDENET_ORIGINAL_CCT,
+    LEDENETAddressableDeviceConfiguration,
     LEDENETOriginalRawState,
     LEDENETRawState,
     ProtocolLEDENET8Byte,
@@ -85,8 +87,9 @@ from .protocol import (
     ProtocolLEDENETAddressableChristmas,
     ProtocolLEDENETCCT,
     ProtocolLEDENETOriginal,
+    ProtocolLEDENETOriginalCCT,
 )
-from .scanner import FluxLEDDiscovery
+from .scanner import FluxLEDDiscovery, is_legacy_device
 from .timer import BuiltInTimer
 from .utils import scaled_color_temp_to_white_levels, utils, white_levels_to_color_temp
 
@@ -97,6 +100,9 @@ PROTOCOL_PROBES: Tuple[Type[ProtocolLEDENET8Byte], Type[ProtocolLEDENETOriginal]
     ProtocolLEDENET8Byte,
     ProtocolLEDENETOriginal,
 )
+PROTOCOL_PROBES_LEGACY: Tuple[
+    Type[ProtocolLEDENETOriginal], Type[ProtocolLEDENET8Byte]
+] = (ProtocolLEDENETOriginal, ProtocolLEDENET8Byte)
 
 PROTOCOL_TYPES = Union[
     ProtocolLEDENET8Byte,
@@ -109,6 +115,7 @@ PROTOCOL_TYPES = Union[
     ProtocolLEDENETAddressableA2,
     ProtocolLEDENETAddressableA3,
     ProtocolLEDENETOriginal,
+    ProtocolLEDENETOriginalCCT,
     ProtocolLEDENETCCT,
     ProtocolLEDENETAddressableChristmas,
 ]
@@ -118,6 +125,12 @@ ADDRESSABLE_PROTOCOLS = {
     PROTOCOL_LEDENET_ADDRESSABLE_A2,
     PROTOCOL_LEDENET_ADDRESSABLE_A3,
 }
+ALL_ADDRESSABLE_PROTOCOLS = (
+    ProtocolLEDENETAddressableA1,
+    ProtocolLEDENETAddressableA2,
+    ProtocolLEDENETAddressableA3,
+)
+ALL_IC_PROTOCOLS = (ProtocolLEDENETAddressableChristmas, *ALL_ADDRESSABLE_PROTOCOLS)
 CHRISTMAS_EFFECTS_PROTOCOLS = {PROTOCOL_LEDENET_ADDRESSABLE_CHRISTMAS}
 OLD_EFFECTS_PROTOCOLS = {PROTOCOL_LEDENET_ADDRESSABLE_A1}
 NEW_EFFECTS_PROTOCOLS = {
@@ -130,6 +143,7 @@ SPEED_ADJUST_WILL_TURN_ON = {
 }
 PROTOCOL_NAME_TO_CLS = {
     PROTOCOL_LEDENET_ORIGINAL: ProtocolLEDENETOriginal,
+    PROTOCOL_LEDENET_ORIGINAL_CCT: ProtocolLEDENETOriginalCCT,
     PROTOCOL_LEDENET_8BYTE: ProtocolLEDENET8Byte,
     PROTOCOL_LEDENET_8BYTE_AUTO_ON: ProtocolLEDENET8ByteAutoOn,
     PROTOCOL_LEDENET_8BYTE_DIMMABLE_EFFECTS: ProtocolLEDENET8ByteDimmableEffects,
@@ -159,7 +173,13 @@ class DeviceType(Enum):
 class LEDENETDevice:
     """An LEDENET Device."""
 
-    def __init__(self, ipaddr: str, port: int = 5577, timeout: float = 5) -> None:
+    def __init__(
+        self,
+        ipaddr: str,
+        port: int = 5577,
+        timeout: float = 5,
+        discovery: Optional[FluxLEDDiscovery] = None,
+    ) -> None:
         """Init the LEDENEt Device."""
         self.ipaddr: str = ipaddr
         self.port: int = port
@@ -168,11 +188,24 @@ class LEDENETDevice:
         self.available: Optional[bool] = None
         self._model_num: Optional[int] = None
         self._model_data: Optional[LEDENETModel] = None
-        self._discovery: Optional[FluxLEDDiscovery] = None
+        self._discovery = discovery
         self._protocol: Optional[PROTOCOL_TYPES] = None
         self._mode: Optional[str] = None
         self._transition_complete_time: float = 0
         self._last_effect_brightness: int = 100
+        self._device_config: Optional[LEDENETAddressableDeviceConfiguration] = None
+
+    def _protocol_probes(
+        self,
+    ) -> Union[
+        Tuple[Type[ProtocolLEDENETOriginal], Type[ProtocolLEDENET8Byte]],
+        Tuple[Type[ProtocolLEDENET8Byte], Type[ProtocolLEDENETOriginal]],
+    ]:
+        """Determine the probe order based on device type."""
+        discovery = self.discovery
+        return (
+            PROTOCOL_PROBES_LEGACY if is_legacy_device(discovery) else PROTOCOL_PROBES
+        )
 
     @property
     def model_num(self) -> int:
@@ -209,7 +242,7 @@ class LEDENETDevice:
     @property
     def model(self) -> str:
         """Return the human readable model description."""
-        if self._discovery and self._discovery[ATTR_MODEL_DESCRIPTION]:
+        if self._discovery and self._discovery.get(ATTR_MODEL_DESCRIPTION):
             return f"{self._discovery[ATTR_MODEL_DESCRIPTION]} (0x{self.model_num:02X})"
         return f"{self.model_data.description} (0x{self.model_num:02X})"
 
@@ -221,7 +254,7 @@ class LEDENETDevice:
         if hasattr(raw_state, "version_number"):
             assert isinstance(raw_state, LEDENETRawState)
             return raw_state.version_number
-        return 1
+        return 0  # old devices report as 0
 
     @property
     def preset_pattern_num(self) -> int:
@@ -279,10 +312,7 @@ class LEDENETDevice:
         """Any white channel is active."""
         assert self.raw_state is not None
         raw_state = self.raw_state
-        if hasattr(raw_state, "cool_white"):
-            assert isinstance(raw_state, LEDENETRawState)
-            return bool(raw_state.warm_white or raw_state.cool_white)
-        return bool(raw_state.warm_white)
+        return bool(raw_state.warm_white or raw_state.cool_white)
 
     @property
     def color_active(self) -> bool:
@@ -320,6 +350,114 @@ class LEDENETDevice:
             self.raw_state.mode, model_data.color_modes
         )
 
+    @property
+    def pixels_per_segment(self) -> Optional[int]:
+        """Return the pixels per segment."""
+        if self._device_config is None:
+            return None
+        return self._device_config.pixels_per_segment
+
+    @property
+    def segments(self) -> Optional[int]:
+        """Return the number of segments."""
+        if self._device_config is None:
+            return None
+        return self._device_config.segments
+
+    @property
+    def music_pixels_per_segment(self) -> Optional[int]:
+        """Return the music pixels per segment."""
+        if self._device_config is None:
+            return None
+        return self._device_config.music_pixels_per_segment
+
+    @property
+    def music_segments(self) -> Optional[int]:
+        """Return the number of music segments."""
+        if self._device_config is None:
+            return None
+        return self._device_config.music_segments
+
+    @property
+    def wiring(self) -> Optional[str]:
+        """Return the sort order as a string."""
+        device_config = self.model_data.device_config
+        if not device_config.wiring:
+            return None
+        if self._device_config:
+            return self._device_config.wiring
+        assert self.raw_state is not None
+        return device_config.num_to_wiring.get(int((self.raw_state.mode & 0xF0) / 16))
+
+    @property
+    def wiring_num(self) -> Optional[int]:
+        """Return the wiring number."""
+        if not self.model_data.device_config.wiring:
+            return None
+        if self._device_config:
+            return self._device_config.wiring_num
+        assert self.raw_state is not None
+        return int((self.raw_state.mode & 0xF0) / 16)
+
+    @property
+    def wirings(self) -> Optional[List[str]]:
+        """Return available wirings for the device."""
+        device_config = self.model_data.device_config
+        if not device_config.wiring:
+            return None
+        if self._device_config:
+            return list(self._device_config.wirings)
+        return list(device_config.wiring_to_num)
+
+    @property
+    def operating_mode(self) -> Optional[str]:
+        """Return the strip mode as a string."""
+        device_config = self.model_data.device_config
+        if not device_config.operating_modes:
+            return None
+        if self._device_config:
+            return self._device_config.operating_mode
+        assert self.raw_state is not None
+        return device_config.num_to_operating_mode.get(self.raw_state.mode & 0x0F)
+
+    @property
+    def operating_mode_num(self) -> Optional[int]:
+        """Return the strip mode as a string."""
+        if not self.model_data.device_config.operating_modes:
+            return None
+        assert self.raw_state is not None
+        return self.raw_state.mode & 0x0F
+
+    @property
+    def operating_modes(self) -> Optional[List[str]]:
+        """Return available operating modes for the device."""
+        if not self.model_data.device_config.operating_modes:
+            return None
+        return list(self.model_data.device_config.operating_mode_to_num)
+
+    @property
+    def ic_type(self) -> Optional[str]:
+        """Return the strip ictype as a string."""
+        if not self.model_data.device_config.ic_type:
+            return None
+        assert self._device_config is not None
+        return self._device_config.ic_type
+
+    @property
+    def ic_type_num(self) -> Optional[int]:
+        """Return the strip ictype as an int."""
+        if not self.model_data.device_config.ic_type:
+            return None
+        assert self._device_config is not None
+        return self._device_config.ic_type_num
+
+    @property
+    def ic_types(self) -> Optional[List[str]]:
+        """Return the ic types."""
+        if not self.model_data.device_config.ic_type:
+            return None
+        return list(self.model_data.device_config.ic_type_to_num)
+
     @property
     def color_mode(self) -> Optional[str]:
         """The current color mode."""
@@ -419,7 +557,6 @@ class LEDENETDevice:
     def cool_white(self) -> int:
         assert self.raw_state is not None
         if self._rgbwwprotocol:
-            assert isinstance(self.raw_state, LEDENETRawState)
             return self.raw_state.cool_white
         return 0
 
@@ -463,7 +600,6 @@ class LEDENETDevice:
         if color_mode == COLOR_MODE_RGBW:
             return round((v_255 + raw_state.warm_white) / 2)
         if color_mode == COLOR_MODE_RGBWW:
-            assert isinstance(raw_state, LEDENETRawState)
             return round((v_255 + raw_state.warm_white + raw_state.cool_white) / 3)
 
         # Default color mode (RGB)
@@ -500,6 +636,12 @@ class LEDENETDevice:
     def set_available(self) -> None:
         self.available = True
 
+    def process_device_config_response(self, msg: bytes) -> None:
+        """Process an IC (strip config) response."""
+        assert isinstance(self._protocol, ALL_IC_PROTOCOLS)
+        self._device_config = self._protocol.parse_strip_setting(msg)
+        _LOGGER.debug("%s: device_config: %s", self.ipaddr, self._device_config)
+
     def process_state_response(self, rx: bytes) -> bool:
         assert self._protocol is not None
 
@@ -692,7 +834,6 @@ class LEDENETDevice:
         # Assume input temperature of between 2700 and 6500 Kelvin, and scale
         # the warm and cold LEDs linearly to provide that
         assert self.raw_state is not None
-        assert isinstance(self.raw_state, LEDENETRawState)
         raw_state = self.raw_state
         temp, brightness = white_levels_to_color_temp(
             raw_state.warm_white, raw_state.cool_white
@@ -726,8 +867,8 @@ class LEDENETDevice:
     @property
     def rgbww(self) -> Tuple[int, int, int, int, int]:
         """Returns red,green,blue,warm,cool."""
-        assert isinstance(self.raw_state, LEDENETRawState)
         raw_state = self.raw_state
+        assert raw_state is not None
         return (
             raw_state.red,
             raw_state.green,
@@ -745,8 +886,8 @@ class LEDENETDevice:
     @property
     def rgbcw(self) -> Tuple[int, int, int, int, int]:
         """Returns red,green,blue,cool,warm."""
-        assert isinstance(self.raw_state, LEDENETRawState)
         raw_state = self.raw_state
+        assert raw_state is not None
         return (
             raw_state.red,
             raw_state.green,
@@ -758,8 +899,8 @@ class LEDENETDevice:
     def getCCT(self) -> Tuple[int, int]:
         if self.color_mode != COLOR_MODE_CCT:
             return (255, 255)
-        assert isinstance(self.raw_state, LEDENETRawState)
         raw_state = self.raw_state
+        assert raw_state is not None
         return (raw_state.warm_white, raw_state.cool_white)
 
     @property
