@@ -8,6 +8,14 @@ import logging
 from typing import List, NamedTuple, Optional, Tuple, Union
 
 from .const import (
+    COLOR_MODE_RGB,
+    COLOR_MODE_RGBW,
+    MUSIC_PIXELS_MAX,
+    MUSIC_PIXELS_PER_SEGMENT_MAX,
+    MUSIC_SEGMENTS_MAX,
+    PIXELS_MAX,
+    PIXELS_PER_SEGMENT_MAX,
+    SEGMENTS_MAX,
     TRANSITION_GRADUAL,
     TRANSITION_JUMP,
     TRANSITION_STROBE,
@@ -25,7 +33,21 @@ class PowerRestoreState(Enum):
 
 class MusicMode(Enum):
     STRIP = 0x26
-    LIGHT_BAR = 0x27
+    LIGHT_SCREEN = 0x27
+
+
+@dataclass
+class LEDENETAddressableDeviceConfiguration:
+    pixels_per_segment: int  # pixels per segment
+    segments: int  # number of segments
+    music_pixels_per_segment: int  # music pixels per segment
+    music_segments: int  # number of music segments
+    wirings: List[str]  # available wirings in the current mode
+    wiring: Optional[str]  # RGB/BRG/GBR etc
+    wiring_num: Optional[int]  # RGB/BRG/GBR number
+    ic_type: Optional[str]  # WS2812B UCS.. etc
+    ic_type_num: Optional[int]  # WS2812B UCS.. number etc
+    operating_mode: Optional[str]  # RGB, RGBW
 
 
 @dataclass
@@ -40,6 +62,7 @@ _LOGGER = logging.getLogger(__name__)
 
 # Protocol names
 PROTOCOL_LEDENET_ORIGINAL = "LEDENET_ORIGINAL"
+PROTOCOL_LEDENET_ORIGINAL_CCT = "LEDENET_ORIGINAL_CCT"
 PROTOCOL_LEDENET_9BYTE = "LEDENET"
 PROTOCOL_LEDENET_9BYTE_AUTO_ON = "LEDENET_AUTO_ON"
 PROTOCOL_LEDENET_9BYTE_DIMMABLE_EFFECTS = "LEDENET_DIMMABLE_EFFECTS"
@@ -65,20 +88,8 @@ LEDENET_ORIGINAL_STATE_RESPONSE_LEN = 11
 LEDENET_STATE_RESPONSE_LEN = 14
 LEDENET_POWER_RESPONSE_LEN = 4
 LEDENET_ADDRESSABLE_STATE_RESPONSE_LEN = 25
-LEDENET_IC_STATE_RESPONSE_LEN = 11
-# pos  0  1  2  3  4  5  6  7  8  9 10
-#    00 63 00 3c 04 00 00 00 00 00 02
-#     |  |  |  |  |  |  |  |  |  |  checksum
-#     |  |  |  |  |  |  |  |  |  ??
-#     |  |  |  |  |  |  |  |  ??
-#     |  |  |  |  |  |  |  ??
-#     |  |  |  |  |  |  ??
-#     |  |  |  |  |  ???
-#     |  |  |  |  ????
-#     |  |  |  ic
-#     |  |  num pixels (16 bit, low byte)
-#     |  num pixels (16 bit, high byte)
-#     msg head
+LEDENET_A1_DEVICE_CONFIG_RESPONSE_LEN = 12
+LEDENET_DEVICE_CONFIG_RESPONSE_LEN = 11
 
 MSG_ORIGINAL_POWER_STATE = "original_power_state"
 MSG_ORIGINAL_STATE = "original_state"
@@ -90,7 +101,8 @@ MSG_STATE = "state"
 MSG_MUSIC_MODE_STATE = "music_mode_state"
 MSG_ADDRESSABLE_STATE = "addressable_state"
 
-MSG_IC_CONFIG = "ic_config"
+MSG_DEVICE_CONFIG = "device_config"
+MSG_A1_DEVICE_CONFIG = "a1_device_config"
 
 
 OUTER_MESSAGE_FIRST_BYTE = 0xB0
@@ -105,7 +117,10 @@ MSG_UNIQUE_START = {
     (0x78,): MSG_ORIGINAL_POWER_STATE,
     (0x66,): MSG_ORIGINAL_STATE,
     (0x81,): MSG_STATE,
-    (0x00, 0x63): MSG_IC_CONFIG,
+    (0x00, 0x63): MSG_DEVICE_CONFIG,
+    (0xF0, 0x63): MSG_DEVICE_CONFIG,
+    (0x0F, 0x63): MSG_DEVICE_CONFIG,
+    (0x63,): MSG_A1_DEVICE_CONFIG,
     (0x72,): MSG_MUSIC_MODE_STATE,
 }
 
@@ -117,7 +132,8 @@ MSG_LENGTHS = {
     MSG_ORIGINAL_STATE: LEDENET_ORIGINAL_STATE_RESPONSE_LEN,
     MSG_STATE: LEDENET_STATE_RESPONSE_LEN,
     MSG_ADDRESSABLE_STATE: LEDENET_ADDRESSABLE_STATE_RESPONSE_LEN,
-    MSG_IC_CONFIG: LEDENET_IC_STATE_RESPONSE_LEN,
+    MSG_DEVICE_CONFIG: LEDENET_DEVICE_CONFIG_RESPONSE_LEN,
+    MSG_A1_DEVICE_CONFIG: LEDENET_A1_DEVICE_CONFIG_RESPONSE_LEN,
 }
 
 OUTER_MESSAGE_WRAPPER = [OUTER_MESSAGE_FIRST_BYTE, 0xB1, 0xB2, 0xB3, 0x00, 0x01, 0x01]
@@ -150,6 +166,7 @@ class LEDENETOriginalRawState(NamedTuple):
     blue: int
     warm_white: int
     check_sum: int
+    cool_white: int
 
 
 # typical response:
@@ -206,6 +223,114 @@ class LEDENETRawState(NamedTuple):
 #     |  model_num (type)
 #     msg head
 #
+RGB_NUM_TO_WIRING = {1: "RGB", 2: "GRB", 3: "BRG"}
+RGB_WIRING_TO_NUM = {v: k for k, v in RGB_NUM_TO_WIRING.items()}
+RGBW_NUM_TO_WIRING = {1: "RGBW", 2: "GRBW", 3: "BRGW"}
+RGBW_WIRING_TO_NUM = {v: k for k, v in RGBW_NUM_TO_WIRING.items()}
+RGBW_NUM_TO_MODE = {4: "RGB&W", 6: "RGB/W"}
+RGBW_MODE_TO_NUM = {v: k for k, v in RGBW_NUM_TO_MODE.items()}
+RGBWW_NUM_TO_WIRING = {
+    1: "RGBCW",
+    2: "GRBCW",
+    3: "BRGCW",
+    4: "RGBWC",
+    5: "GRBWC",
+    6: "BRGWC",
+    7: "WRGBC",
+    8: "WGRBC",
+    9: "WBRGC",
+    10: "CRGBW",
+    11: "CBRBW",
+    12: "CBRGW",
+    13: "WCRGB",
+    14: "WCGRB",
+    15: "WCBRG",
+}
+RGBWW_WIRING_TO_NUM = {v: k for k, v in RGBWW_NUM_TO_WIRING.items()}
+RGBWW_NUM_TO_MODE = {5: "RGB&CCT", 7: "RGB/CCT"}
+RGBWW_MODE_TO_NUM = {v: k for k, v in RGBWW_NUM_TO_MODE.items()}
+
+ADDRESSABLE_RGB_NUM_TO_WIRING = {
+    0: "RGB",
+    1: "RBG",
+    2: "GRB",
+    3: "GBR",
+    4: "BRG",
+    5: "BGR",
+}
+ADDRESSABLE_RGB_WIRING_TO_NUM = {v: k for k, v in ADDRESSABLE_RGB_NUM_TO_WIRING.items()}
+ADDRESSABLE_RGBW_NUM_TO_WIRING = {
+    0: "RGBW",
+    1: "RBGW",
+    2: "GRBW",
+    3: "GBRW",
+    4: "BRGW",
+    5: "BGRW",
+    6: "WRGB",
+    7: "WRBG",
+    8: "WGRB",
+    9: "WGBR",
+    10: "WBRG",
+    11: "WBGR",
+}
+ADDRESSABLE_RGBW_WIRING_TO_NUM = {
+    v: k for k, v in ADDRESSABLE_RGBW_NUM_TO_WIRING.items()
+}
+
+
+A1_NUM_TO_PROTOCOL = {
+    1: "UCS1903",
+    2: "SM16703",
+    3: "WS2811",
+    4: "WS2812B",
+    5: "SK6812",
+    6: "INK1003",
+    7: "WS2801",
+    8: "LB1914",
+}
+A1_PROTOCOL_TO_NUM = {v: k for k, v in A1_NUM_TO_PROTOCOL.items()}
+
+A1_NUM_TO_OPERATING_MODE = {
+    1: COLOR_MODE_RGB,
+    2: COLOR_MODE_RGB,
+    3: COLOR_MODE_RGB,
+    4: COLOR_MODE_RGB,
+    5: COLOR_MODE_RGB,
+    6: COLOR_MODE_RGB,
+    7: COLOR_MODE_RGB,
+    8: COLOR_MODE_RGB,
+}
+A1_OPERATING_MODE_TO_NUM = {v: k for k, v in A1_NUM_TO_OPERATING_MODE.items()}
+
+NEW_ADDRESSABLE_NUM_TO_PROTOCOL = {
+    1: "WS2812B",
+    2: "SM16703",
+    3: "SM16704",
+    4: "WS2811",
+    5: "UCS1903",
+    6: "SK6812",
+    7: "SK6812RGBW",
+    8: "INK1003",
+    9: "UCS2904B",
+}
+NEW_ADDRESSABLE_PROTOCOL_TO_NUM = {
+    v: k for k, v in NEW_ADDRESSABLE_NUM_TO_PROTOCOL.items()
+}
+
+NEW_ADDRESSABLE_NUM_TO_OPERATING_MODE = {
+    1: COLOR_MODE_RGB,
+    2: COLOR_MODE_RGB,
+    3: COLOR_MODE_RGB,
+    4: COLOR_MODE_RGB,
+    5: COLOR_MODE_RGB,
+    6: COLOR_MODE_RGB,
+    7: COLOR_MODE_RGBW,
+    8: COLOR_MODE_RGB,
+    9: COLOR_MODE_RGB,
+}
+NEW_ADDRESSABLE_OPERATING_MODE_TO_NUM = {
+    v: k for k, v in NEW_ADDRESSABLE_NUM_TO_OPERATING_MODE.items()
+}
 
 
 class ProtocolBase:
@@ -262,7 +387,7 @@ class ProtocolBase:
         """Extract the inner message from a wrapped message."""
         return msg[10:-1]
 
-    def is_valid_ic_response(self, data: bytes) -> bool:
+    def is_valid_device_config_response(self, data: bytes) -> bool:
         """Check if a message is a valid ic state response."""
         return False
 
@@ -477,11 +602,7 @@ class ProtocolLEDENETOriginal(ProtocolBase):
 
     def is_valid_state_response(self, raw_state: bytes) -> bool:
         """Check if a state response is valid."""
-        return (
-            len(raw_state) == self.state_response_length
-            and raw_state[0] == 0x66
-            and raw_state[1] == 0x01
-        )
+        return len(raw_state) == self.state_response_length and raw_state[0] == 0x66
 
     def construct_state_query(self) -> bytearray:
         """The bytes to send for a query request."""
@@ -521,7 +642,37 @@ class ProtocolLEDENETOriginal(ProtocolBase):
 
     def named_raw_state(self, raw_state: bytes) -> LEDENETOriginalRawState:
         """Convert raw_state to a namedtuple."""
-        return LEDENETOriginalRawState(*raw_state)
+        raw_bytearray = bytearray([*raw_state, 0])
+        return LEDENETOriginalRawState(*raw_bytearray)
+
+
+class ProtocolLEDENETOriginalCCT(ProtocolLEDENETOriginal):
+    @property
+    def name(self) -> str:
+        """The name of the protocol."""
+        return PROTOCOL_LEDENET_ORIGINAL_CCT
+
+    def construct_levels_change(
+        self,
+        persist: int,
+        red: int,
+        green: int,
+        blue: int,
+        warm_white: int,
+        cool_white: int,
+        write_mode: LevelWriteMode,
+    ) -> bytearray:
+        """The bytes to send for a level change request."""
+        # sample message for original LEDENET protocol (w/o checksum at end)
+        #  0  1  2  3  4
+        # 56 90 fa 77 aa
+        #  |  |  |  |  |
+        #  |  |  |  |  terminator
+        #  |  |  |  blue
+        #  |  |  green
+        #  |  red
+        #  head
+        return self.construct_message(bytearray([0x56, red, green, 0xAA]))
 
 
 class ProtocolLEDENET8Byte(ProtocolBase):
@@ -680,6 +831,51 @@ class ProtocolLEDENET8Byte(ProtocolBase):
         # 0x01 - Gradual
         return [self.construct_message(bytearray([0x73, 0x01, sensitivity, 0x0F]))]
 
+    def construct_device_config(
+        self,
+        operating_mode: Optional[int],
+        wiring: Optional[int],
+        ic_type: Optional[int],  # ic type
+        pixels_per_segment: Optional[int],  # pixels per segment
+        segments: Optional[int],  # number of segments
+        music_pixels_per_segment: Optional[int],  # music pixels per segment
+        music_segments: Optional[int],  # number of music segments
+    ) -> bytearray:
+        """The bytes to send to change device config.
+
+        RGBW 0x06
+        62 06 02 0f 79 - RGB/W GRB W
+        62 04 02 0f 77 - RGB&W GRB W
+        62 04 01 0f 77 - RGB&W RGB W
+        62 04 03 0f 77 - RGB&W BRG W
+
+        RGBCW 0x07
+
+        62 05 0f 0f 85 - RGB&CCT / WCBRG
+        62 07 0f 0f 87 - RGB/CCT / WCBRG
+        62 07 01 0f 79 - RGB/CCT / RGBCW
+        62 07 02 0f 7a - RGB/CCT / GRBCW
+        62 07 0c 0f 84 - RGB/CCT / CBRGW
+
+        RGB 0x33 / 0x08
+
+        62 00 01 0f 73 - RGB
+        62 00 02 0f 73 - GRB
+        62 00 03 0f 73 - BRG
+
+        0x25
+        62 01 0f 72 - DIM
+        62 02 0f 73 - CCT
+        62 03 0f 74 - RGB
+        62 04 0f 74 - RGB&W
+        62 05 0f 74 - RGB&CCT
+        """
+        msg = bytearray([0x62, operating_mode or 0x00])
+        if wiring:
+            msg.append(wiring)
+        msg.append(0x0F)
+        return self.construct_message(msg)
+
 
 class ProtocolLEDENET8ByteAutoOn(ProtocolLEDENET8Byte):
     """Protocol that uses 8 bytes, and turns on by changing levels or effects."""
@@ -877,16 +1073,26 @@ class ProtocolLEDENET9ByteDimmableEffects(ProtocolLEDENET9ByteAutoOn):
 
 
 class ProtocolLEDENETAddressableBase(ProtocolLEDENET9Byte):
-    def construct_request_strip_setting(self) -> bytearray:
-        return self.construct_message(bytearray([0x63, 0x12, 0x21]))
+    """Base class for addressable protocols."""
 
 
 class ProtocolLEDENETAddressableA1(ProtocolLEDENETAddressableBase):
+    def construct_request_strip_setting(self) -> bytearray:
+        return bytearray([0x63, 0x12, 0x21, 0x36])
+
     @property
     def name(self) -> str:
         """The name of the protocol."""
         return PROTOCOL_LEDENET_ADDRESSABLE_A1
 
+    def is_valid_device_config_response(self, data: bytes) -> bool:
+        """Check if a message is a valid ic state response."""
+        return (
+            len(data) == LEDENET_A1_DEVICE_CONFIG_RESPONSE_LEN
+            and _message_type_from_start_of_msg(data) == MSG_A1_DEVICE_CONFIG
+            and self.is_checksum_correct(data)
+        )
+
     @property
     def power_push_updates(self) -> bool:
         """If True the protocol pushes power state updates when controlled via ir/rf/app."""
@@ -911,11 +1117,109 @@ class ProtocolLEDENETAddressableA1(ProtocolLEDENETAddressableBase):
             bytearray([0x61, effect >> 8, effect & 0xFF, speed, 0x0F])
         )
 
+    def parse_strip_setting(self, msg: bytes) -> LEDENETAddressableDeviceConfiguration:
+        """Parse a strip settings message."""
+        # pos  0  1  2  3  4  5  6  7  8  9 10 11
+        #    63 00 32 05 00 00 00 00 00 00 02 9c
+        #     |  |  |  |  |  |  |  |  |  |  |  |
+        #     |  |  |  |  |  |  |  |  |  |  |  checksum
+        #     |  |  |  |  |  |  |  |  |  |  wiring type (0 indexed, RGB or RGBW)
+        #     |  |  |  |  |  |  |  |  |  ?? always 00
+        #     |  |  |  |  |  |  |  |  ?? always 00
+        #     |  |  |  |  |  |  |  n?? always 00
+        #     |  |  |  |  |  |  ?? always 00
+        #     |  |  |  |  |  ?? always 00
+        #     |  |  |  |  ?? always 00
+        #     |  |  |  ic type (01=UCS1903, 02=SM16703, 03=WS2811, 04=WS2812B, 05=SK6812, 06=INK1003, 07=WS2801, 08=LB1914)
+        #     |  |  num pixels (16 bit, low byte)
+        #     |  num pixels (16 bit, high byte)
+        #     msg head
+        #
+        high_byte = msg[1]
+        low_byte = msg[2]
+        pixels_per_segment = (high_byte << 8) + low_byte
+        _LOGGER.debug(
+            "Pixel count (high: %s, low: %s) is: %s",
+            hex(high_byte),
+            hex(low_byte),
+            pixels_per_segment,
+        )
+        segments = msg[5]
+        _LOGGER.debug(
+            "Segment count (%s) is: %s",
+            hex(segments),
+            segments,
+        )
+        return LEDENETAddressableDeviceConfiguration(
+            pixels_per_segment=pixels_per_segment,
+            segments=segments,
+            music_pixels_per_segment=0,
+            music_segments=0,
+            wirings=list(ADDRESSABLE_RGB_WIRING_TO_NUM),
+            wiring_num=msg[10],
+            wiring=ADDRESSABLE_RGB_NUM_TO_WIRING.get(msg[10]),
+            ic_type=A1_NUM_TO_PROTOCOL.get(msg[3]),
+            ic_type_num=msg[3],
+            operating_mode=A1_NUM_TO_OPERATING_MODE.get(msg[3]),
+        )
+
+    def construct_device_config(
+        self,
+        operating_mode: Optional[int],
+        wiring: Optional[int],
+        ic_type: Optional[int],  # ic type
+        pixels_per_segment: Optional[int],  # pixels per segment
+        segments: Optional[int],  # number of segments
+        music_pixels_per_segment: Optional[int],  # music pixels per segment
+        music_segments: Optional[int],  # number of music segments
+    ) -> bytearray:
+        """The bytes to send to change device config.
+        pos  0  1  2  3  4  5  6  7  8  9 10 11 12
+            62 04 00 04 00 00 00 00 00 00 02 f0 5c <- checksum
+             |  |  |  |  |  |  |  |  |  |  |  |
+             |  |  |  |  |  |  |  |  |  |  |  always 0xf0
+             |  |  |  |  |  |  |  |  |  |  wiring type (0 indexed, RGB or RGBW)
+             |  |  |  |  |  |  |  |  |  ?? always 00
+             |  |  |  |  |  |  |  |  ?? always 00
+             |  |  |  |  |  |  |  n?? always 00
+             |  |  |  |  |  |  ?? always 00
+             |  |  |  |  |  ?? always 00
+             |  |  |  |  ?? always 00
+             |  |  |  ic type (01=UCS1903, 02=SM16703, 03=WS2811, 04=WS2812B, 05=SK6812, 06=INK1003, 07=WS2801, 08=LB1914)
+             |  |  num pixels (16 bit, low byte)
+             |  num pixels (16 bit, high byte)
+             msg head
+
+        """
+        assert ic_type is not None
+        assert pixels_per_segment is not None
+        assert wiring is not None
+        return self.construct_message(
+            bytearray(
+                [
+                    0x62,
+                    pixels_per_segment >> 8,
+                    pixels_per_segment & 0xFF,
+                    ic_type,
+                    0x00,
+                    0x00,
+                    0x00,
+                    0x00,
+                    0x00,
+                    0x00,
+                    wiring,
+                    0xF0,
+                ]
+            )
+        )
+
 
 class ProtocolLEDENETAddressableA2(ProtocolLEDENETAddressableBase):
 
     # ic response
     # 0x96 0x63 0x00 0x32 0x00 0x01 0x01 0x04 0x32 0x01 0x64 (11)
+    def construct_request_strip_setting(self) -> bytearray:
+        return self.construct_message(bytearray([0x63, 0x12, 0x21, 0x0F]))
 
     @property
     def name(self) -> str:
@@ -938,6 +1242,14 @@ class ProtocolLEDENETAddressableA2(ProtocolLEDENETAddressableBase):
         """If True the device must be turned on before setting level/patterns/modes."""
         return False
 
+    def is_valid_device_config_response(self, data: bytes) -> bool:
+        """Check if a message is a valid ic state response."""
+        return (
+            len(data) == LEDENET_DEVICE_CONFIG_RESPONSE_LEN
+            and _message_type_from_start_of_msg(data) == MSG_DEVICE_CONFIG
+            and self.is_checksum_correct(data)
+        )
+
     def construct_preset_pattern(
         self, pattern: int, speed: int, brightness: int
     ) -> bytearray:
@@ -1028,8 +1340,8 @@ class ProtocolLEDENETAddressableA2(ProtocolLEDENETAddressableBase):
             foreground_color = (0xFF, 0x00, 0x00)
         if background_color is None:
             background_color = (0x00, 0x00, 0x00)
-        if effect and not (1 <= effect <= 30):
-            raise ValueError("Effect must be between 1 and 30")
+        if effect and not (1 <= effect <= 16):
+            raise ValueError("Effect must be between 1 and 16")
         if mode and not (0x26 <= mode <= 0x27):
             raise ValueError("Mode must be between 0x26 and 0x27")
 
@@ -1039,7 +1351,8 @@ class ProtocolLEDENETAddressableA2(ProtocolLEDENETAddressableBase):
                     [
                         0x73,
                         0x01,
-                        mode or 0x26,  # strip mode 0x26, light bar mode 0x27
+                        mode
+                        or MusicMode.STRIP.value,  # strip mode 0x26, light screen mode 0x27
                         effect or 0x01,
                         *foreground_color,
                         *background_color,
@@ -1050,8 +1363,135 @@ class ProtocolLEDENETAddressableA2(ProtocolLEDENETAddressableBase):
             )
         ]
 
+    def parse_strip_setting(self, msg: bytes) -> LEDENETAddressableDeviceConfiguration:
+        """Parse a strip settings message."""
+        # pos  0  1  2  3  4  5  6  7  8  9 10
+        #    00 63 01 2c 00 01 07 08 96 01 45
+        #     |  |  |  |  |  |  |  |  |  |  |
+        #     |  |  |  |  |  |  |  |  |  |  checksum
+        #     |  |  |  |  |  |  |  |  |  |
+        #     |  |  |  |  |  |  |  |  |  segments (music mode)
+        #     |  |  |  |  |  |  |  |  num pixels (music mode)
+        #     |  |  |  |  |  |  |  wiring type (0 indexed, RGB or RGBW)
+        #     |  |  |  |  |  |  ic type (01=WS2812B, 02=SM16703, 03=SM16704, 04=WS2811, 05=UCS1903, 06=SK6812, 07=SK6812RGBW, 08=INK1003, 09=UCS2904B)
+        #     |  |  |  |  |  segments
+        #     |  |  |  |  ?? (always 0x00)
+        #     |  |  |  num pixels (16 bit, low byte)
+        #     |  |  num pixels (16 bit, high byte)
+        #     |  msg head
+        #     msg head
+        #
+        high_byte = msg[2]
+        low_byte = msg[3]
+        pixels_per_segment = (high_byte << 8) + low_byte
+        _LOGGER.debug("bytes: %s", msg)
+        _LOGGER.debug(
+            "Pixel count (high: %s, low: %s) is: %s",
+            hex(high_byte),
+            hex(low_byte),
+            pixels_per_segment,
+        )
+        segments = msg[5]
+        _LOGGER.debug(
+            "Segment count (%s) is: %s",
+            hex(segments),
+            segments,
+        )
+        if NEW_ADDRESSABLE_NUM_TO_OPERATING_MODE.get(msg[6]) == COLOR_MODE_RGBW:
+            wirings = ADDRESSABLE_RGBW_NUM_TO_WIRING
+        else:
+            wirings = ADDRESSABLE_RGB_NUM_TO_WIRING
+        return LEDENETAddressableDeviceConfiguration(
+            pixels_per_segment=pixels_per_segment,
+            segments=segments,
+            music_pixels_per_segment=msg[8],
+            music_segments=msg[9],
+            wirings=list(wirings.values()),
+            wiring_num=msg[7],
+            wiring=wirings.get(msg[7]),
+            ic_type=NEW_ADDRESSABLE_NUM_TO_PROTOCOL.get(msg[6]),
+            ic_type_num=msg[6],
+            operating_mode=NEW_ADDRESSABLE_NUM_TO_OPERATING_MODE.get(msg[6]),
+        )
+
+    def construct_device_config(
+        self,
+        operating_mode: Optional[int],
+        wiring: Optional[int],
+        ic_type: Optional[int],  # ic type
+        pixels_per_segment: Optional[int],  # pixels per segment
+        segments: Optional[int],  # number of segments
+        music_pixels_per_segment: Optional[int],  # music pixels per segment
+        music_segments: Optional[int],  # number of music segments
+    ) -> bytearray:
+        """The bytes to send to change device config.
+        pos  0  1  2  3  4  5  6  7  8  9 10
+            62 01 2c 00 06 01 04 32 01 0f dc
+             |  |  |  |  |  |  |  |  |  |  |
+             |  |  |  |  |  |  |  |  |  |  |
+             |  |  |  |  |  |  |  |  |  |  checksum
+             |  |  |  |  |  |  |  |  |  ?? always 0x0f
+             |  |  |  |  |  |  |  |  segments (music mode)
+             |  |  |  |  |  |  |  num pixels (music mode)
+             |  |  |  |  |  |  wiring type (0 indexed, RGB or RGBW)
+             |  |  |  |  |  ic type (01=WS2812B, 02=SM16703, 03=SM16704, 04=WS2811, 05=UCS1903, 06=SK6812, 07=SK6812RGBW, 08=INK1003, 09=UCS2904B)
+             |  |  |  |  segments
+             |  |  |  ?? always 00
+             |  |  num pixels (16 bit, low byte)
+             |  num pixels (16 bit, high byte)
+             msg head
+
+
+        """
+        assert ic_type is not None
+        assert pixels_per_segment is not None
+        assert segments is not None
+        assert music_pixels_per_segment is not None
+        assert music_segments is not None
+        assert wiring is not None
+        pixels_per_segment = max(1, min(pixels_per_segment, PIXELS_PER_SEGMENT_MAX))
+        segments = max(1, min(segments, SEGMENTS_MAX))
+        if pixels_per_segment * segments > PIXELS_MAX:
+            segments = int(PIXELS_MAX / pixels_per_segment)
+        music_pixels_per_segment = max(
+            1, min(music_pixels_per_segment, MUSIC_PIXELS_PER_SEGMENT_MAX)
+        )
+        music_segments = max(1, min(music_segments, MUSIC_SEGMENTS_MAX))
+        if music_pixels_per_segment * music_segments > MUSIC_PIXELS_MAX:
+            music_segments = int(MUSIC_PIXELS_MAX / music_pixels_per_segment)
+        if (
+            pixels_per_segment <= MUSIC_PIXELS_PER_SEGMENT_MAX
+            and segments <= MUSIC_SEGMENTS_MAX
+            and pixels_per_segment * segments <= MUSIC_PIXELS_MAX
+        ):
+            # If the pixels_per_segment and segments can accomate music
+            # mode then we sync them
+            music_pixels_per_segment = pixels_per_segment
+            music_segments = segments
+        return self.construct_message(
+            bytearray(
+                [
+                    0x62,
+                    pixels_per_segment >> 8,
+                    pixels_per_segment & 0xFF,
+                    0x00,
+                    segments,
+                    ic_type,
+                    wiring,
+                    music_pixels_per_segment,
+                    music_segments,
+                    0xF0,
+                ]
+            )
+        )
+
 
 class ProtocolLEDENETAddressableA3(ProtocolLEDENETAddressableA2):
+    def construct_request_strip_setting(self) -> bytearray:
+        return self.construct_wrapped_message(
+            super().construct_request_strip_setting(),
+            inner_pre_constructed=True,
+        )
 
     # ic response
     # 0x00 0x63 0x00 0x32 0x00 0x01 0x04 0x03 0x32 0x01 0xD0 (11)
@@ -1066,14 +1506,6 @@ class ProtocolLEDENETAddressableA3(ProtocolLEDENETAddressableA2):
         """If the protocol supports zones."""
         return True
 
-    def is_valid_ic_response(self, data: bytes) -> bool:
-        """Check if a message is a valid ic state response."""
-        if len(data) != LEDENET_IC_STATE_RESPONSE_LEN:
-            return False
-        if not data.startswith(bytearray([0x00, 0x63])):
-            return False
-        return self.is_checksum_correct(data)
-
     @property
     def name(self) -> str:
         """The name of the protocol."""
@@ -1262,6 +1694,30 @@ class ProtocolLEDENETAddressableA3(ProtocolLEDENETAddressableA2):
         msg.append(0x00)
         return self.construct_wrapped_message(msg)
 
+    def construct_device_config(
+        self,
+        operating_mode: Optional[int],
+        wiring: Optional[int],
+        ic_type: Optional[int],  # ic type
+        pixels_per_segment: Optional[int],  # pixels per segment
+        segments: Optional[int],  # number of segments
+        music_pixels_per_segment: Optional[int],  # music pixels per segment
+        music_segments: Optional[int],  # number of music segments
+    ) -> bytearray:
+        """The bytes to send to change device config."""
+        return self.construct_wrapped_message(
+            super().construct_device_config(
+                operating_mode,
+                wiring,
+                ic_type,
+                pixels_per_segment,
+                segments,
+                music_pixels_per_segment,
+                segments,
+            ),
+            inner_pre_constructed=True,
+        )
+
 
 class ProtocolLEDENETCCT(ProtocolLEDENET9Byte):
 
@@ -1499,3 +1955,18 @@ class ProtocolLEDENETAddressableChristmas(ProtocolLEDENETAddressableBase):
                 bytearray([0x00, points - remaining, *rgb_list[-1], 0x00, 0x00, 0xFF])
             )
         return self.construct_wrapped_message(msg)
+
+    def parse_strip_setting(self, msg: bytes) -> LEDENETAddressableDeviceConfiguration:
+        """Parse a strip settings message."""
+        return LEDENETAddressableDeviceConfiguration(
+            pixels_per_segment=6,
+            segments=1,
+            music_pixels_per_segment=0,
+            music_segments=0,
+            wirings=[],
+            wiring_num=None,
+            wiring=None,
+            ic_type=None,
+            ic_type_num=None,
+            operating_mode=COLOR_MODE_RGB,
+        )
