@@ -50,11 +50,23 @@ class FluxLEDDiscovery(TypedDict):
     remote_access_port: Optional[int]  # the remote access port
 
 
-def create_udp_socket() -> socket.socket:
+def is_legacy_device(discovery: Optional[FluxLEDDiscovery]) -> bool:
+    """Check if a discovery is a legacy device."""
+    if not discovery:
+        return False
+    return bool(discovery.get(ATTR_VERSION_NUM) and not discovery.get(ATTR_MODEL_NUM))
+
+
+def create_udp_socket(discovery_port: int) -> socket.socket:
     """Create a udp socket used for communicating with the device."""
     sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
     sock.setsockopt(socket.SOL_SOCKET, socket.SO_BROADCAST, 1)
-    sock.bind(("", 0))
+    try:
+        # Legacy devices require source port to be the discovery port
+        sock.bind(("", discovery_port))
+    except OSError as err:
+        _LOGGER.debug("Port %s is not available: %s", discovery_port, err)
+        sock.bind(("", 0))
     sock.setblocking(False)
     return sock
 
@@ -91,13 +103,16 @@ def _process_version_message(data: FluxLEDDiscovery, decoded_data: str) -> None:
     """
     version_data = decoded_data[4:].replace("\r", "")
     data_split = version_data.split("_", 4)
-    if len(data_split) < 2:
-        return
-    try:
-        data[ATTR_MODEL_NUM] = int(data_split[0], 16)
-        data[ATTR_VERSION_NUM] = int(data_split[1], 16)
-    except ValueError:
+    if len(data_split) == 1:
+        with contextlib.suppress(ValueError):
+            data[ATTR_VERSION_NUM] = int(data_split[0], 16)
         return
+    if len(data_split) >= 2:
+        try:
+            data[ATTR_MODEL_NUM] = int(data_split[0], 16)
+            data[ATTR_VERSION_NUM] = int(data_split[1], 16)
+        except ValueError:
+            return
     assert data[ATTR_MODEL_NUM] is not None
     if len(data_split) >= 3:
         firmware_date = data_split[2]
@@ -167,7 +182,7 @@ class BulbScanner:
         return self.found_bulbs
 
     def _create_socket(self) -> socket.socket:
-        return create_udp_socket()
+        return create_udp_socket(self.DISCOVERY_PORT)
 
     def _destination_from_address(self, address: Optional[str]) -> Tuple[str, int]:
         if address is None:
@@ -194,7 +209,7 @@ class BulbScanner:
         if address is None or address not in response_list:
             return False
         response = response_list[address]
-        return (
+        return is_legacy_device(response) or (
             response[ATTR_MODEL_NUM] is not None
             and response[ATTR_REMOTE_ACCESS_ENABLED] is not None
         )
